@@ -67,18 +67,6 @@ $example->Annotate(text=>'Magick',geometry=>'+0+20',font=>'Generic.ttf',
   fill=>'gold',gravity=>'North',pointsize=>14);
 push(@$images,$example);
 
-print "Auto-gamma...\n";
-$example=$model->Clone();
-$example->Label('Auto Gamma');
-$example->AutoGamma();
-push(@$images,$example);
-
-print "Auto-level...\n";
-$example=$model->Clone();
-$example->Label('Auto Level');
-$example->AutoLevel();
-push(@$images,$example);
-
 print "Blur...\n";
 $example=$model->Clone();
 $example->Label('Blur');
@@ -103,12 +91,6 @@ $example->Label('Charcoal');
 $example->Charcoal('0x1');
 push(@$images,$example);
 
-print "ColorMatrix...\n";
-$example=$model->Clone();
-$example->Label('ColorMatrix');
-$example->ColorMatrix([1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1]);
-push(@$images,$example);
-
 print "Composite...\n";
 $example=$model->Clone();
 $example->Label('Composite');
@@ -125,8 +107,8 @@ print "Contrast Stretch...\n";
 $example=$model->Clone();
 $example->Label('Contrast Stretch');
 $example->ContrastStretch('5%');
-push(@$images,$example);
 
+push(@$images,$example);
 print "Convolve...\n";
 $example=$model->Clone();
 $example->Label('Convolve');
@@ -149,7 +131,7 @@ push(@$images,$example);
 print "Distort...\n";
 $example=$model->Clone();
 $example->Label('Distort');
-$example->Distort(method=>'arc',points=>[60],'virtual-pixel'=>'white');
+$example->Distort(type=>'arc',points=>[120],'virtual-pixel'=>'white');
 push(@$images,$example);
 
 print "Draw...\n";
@@ -229,7 +211,7 @@ push(@$images,$gradient);
 print "Grayscale...\n";
 $example=$model->Clone();
 $example->Label('Grayscale');
-$example->Set(type=>'grayscale');
+$example->Quantize(colorspace=>'gray');
 push(@$images,$example);
 
 print "Implode...\n";
@@ -258,17 +240,10 @@ push(@$images,$example);
 $example=$model->Clone();
 
 print "Monochrome...\n";
-$example=$model->Clone();
 $example->Label('Monochrome');
 $example->Quantize(colorspace=>'gray',colors=>2,dither=>'false');
 push(@$images,$example);
 
-print "Morphology...\n";
-$example=$model->Clone();
-$example->Label('Morphology');
-$example->Morphology(method=>'Dilate',kernel=>'Diamond',iterations=>3);
-push(@$images,$example);
-
 print "Motion Blur...\n";
 $example=$model->Clone();
 $example->Label('Motion Blur');
@@ -307,12 +282,6 @@ $example->Label('Polaroid');
 $example->Polaroid(caption=>'Magick',rotate=>-5.0,gravity=>'center');
 push(@$images,$example);
 
-print "Posterize...\n";
-$example=$model->Clone();
-$example->Label('Posterize');
-$example->Posterize(5);
-push(@$images,$example);
-
 print "Quantize...\n";
 $example=$model->Clone();
 $example->Label('Quantize');
@@ -331,6 +300,13 @@ $example->Label('Raise');
 $example->Raise('10x10');
 push(@$images,$example);
 
+push(@$images,$example);
+print "Recolor...\n";
+$example=$model->Clone();
+$example->Label('Recolor');
+$example->Recolor([1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1]);
+push(@$images,$example);
+
 print "Reduce Noise...\n";
 $example=$model->Clone();
 $example->Label('Reduce Noise');
@@ -397,13 +373,6 @@ $example->Label('Shear');
 $example->Shear('-20x20');
 push(@$images,$example);
 
-print "Sketch...\n";
-$example=$model->Clone();
-$example->Label('Sketch');
-$example->Set(colorspace=>'Gray');
-$example->Sketch('0x20+120');
-push(@$images,$example);
-
 print "Sigmoidal Contrast...\n";
 $example=$model->Clone();
 $example->Label('Sigmoidal Contrast');
